/*
 * Copyright 2012-2017 Red Hat, Inc.
 *
 * This file is part of Thermostat.
 *
 * Thermostat is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2, or (at your
 * option) any later version.
 *
 * Thermostat is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Thermostat; see the file COPYING.  If not see
 * <http://www.gnu.org/licenses/>.
 *
 * Linking this code with other modules is making a combined work
 * based on this code.  Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this code give
 * you permission to link this code with independent modules to
 * produce an executable, regardless of the license terms of these
 * independent modules, and to copy and distribute the resulting
 * executable under terms of your choice, provided that you also
 * meet, for each linked independent module, the terms and conditions
 * of the license of that module.  An independent module is a module
 * which is not derived from or based on this code.  If you modify
 * this code, you may extend this exception to your version of the
 * library, but you are not obligated to do so.  If you do not wish
 * to do so, delete this exception statement from your version.
 */

package com.redhat.thermostat.common.swaggercombine;

import com.redhat.thermostat.common.swaggercombine.SwaggerCombineContext;
import org.junit.Test;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

public class SwaggerCombineContextTest {

    private static String SOME_INVALID_FILE = "/some/file/name";
    private static String SOME_MISSING_FILE = "/some_missing_file.yaml";
    private static final String SOME_VALID_FILE = "/systems-swagger.yaml";
    @Test
    public void testQuiet() {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        ctx.quiet(true);
        assertTrue(ctx.isQuiet());
        ctx.quiet(false);
        assertFalse(ctx.isQuiet());
    }

    @Test
    public void testUseTemplate() {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        ctx.useTemplate(true);
        assertTrue(ctx.isUseTemplate());
        ctx.useTemplate(false);
        assertFalse(ctx.isUseTemplate());
    }

    @Test
    public void testPretty() {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        ctx.prettyPrint(true);
        assertTrue(ctx.isPretty());
        ctx.prettyPrint(false);
        assertFalse(ctx.isPretty());
    }

    @Test
    public void testLint() {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        ctx.lint(true);
        assertTrue(ctx.isLint());
        ctx.lint(false);
        assertFalse(ctx.isLint());
    }

    @Test
    public void testFormat() {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        assertEquals(SwaggerCombineContext.OutputFormat.NONE, ctx.getFmt());
        ctx.produce(SwaggerCombineContext.OutputFormat.JSON);
        assertEquals(SwaggerCombineContext.OutputFormat.JSON, ctx.getFmt());
        ctx.produce(SwaggerCombineContext.OutputFormat.YAML);
        assertEquals(SwaggerCombineContext.OutputFormat.YAML, ctx.getFmt());
    }

    @Test(expected = IOException.class)
    public void testInvalidFiles() throws IOException {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        assertEquals(0, ctx.getAPIList().size());
        ctx.addMicroAPI(new File(SOME_INVALID_FILE));
        fail();
    }

    @Test(expected = FileNotFoundException.class)
    public void testMissingFiles() throws IOException {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        assertEquals(0, ctx.getAPIList().size());
        ctx.addMicroAPI(new File(SOME_MISSING_FILE));
        fail();
    }

    @Test
    public void testFiles() throws IOException {
        final SwaggerCombineContext ctx = new SwaggerCombineContext();
        assertEquals(0, ctx.getAPIList().size());
        ctx.addMicroAPI(new File(getClass().getResource(SOME_VALID_FILE).getFile()));
        assertEquals(1, ctx.getAPIList().size());
    }

    private boolean contains(String[] array, String s) {
        for (final String s2 : array) {
            if (s2.equals(s)) {
                return true;
            }
        }
        return false;
    }
}
